@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.12 2005/01/28 22:29:41 chpe Exp $
+ *  $Id: extensions-manager-ui.c,v 1.16 2005/10/30 19:21:10 chpe Exp $
  */
 
 #include "config.h"
@@ -40,6 +40,7 @@
 #include <glib/gi18n-lib.h>
 
 #define IGNORE_SELF /* Don't display *this* extension in the list */
+#define GROUP	"Epiphany Extension"
 
 #define EXTENSIONS_MANAGER_UI_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), TYPE_EXTENSIONS_MANAGER_UI, ExtensionsManagerUIPrivate))
 
@@ -72,19 +73,12 @@ EphyDialogProperty properties [] =
 enum
 {
 	COL_INFO,	/* EphyExtensionInfo* */
+	COL_NAME,	/* Search column */
 	COL_TOGGLE,	/* enabled? */
 	COL_DISPLAY,	/* String representation */
 	N_COLUMNS
 };
 
-/* glade callbacks */
-void extensions_manager_ui_response_cb (GtkWidget *button,
-					int response,
-				  	GObject *dialog);
-void extensions_manager_ui_info_dialog_response_cb (GtkWidget *button,
-						    int response,
-						    GObject *dialog);
-
 static void extensions_manager_ui_class_init	(ExtensionsManagerUIClass *klass);
 static void extensions_manager_ui_init		(ExtensionsManagerUI *dialog);
 
@@ -122,7 +116,7 @@ extensions_manager_ui_register_type (GTypeModule *module)
 	return type;
 }
 
-void
+static void
 extensions_manager_ui_response_cb (GtkWidget *widget,
 				   int response,
 				   GObject *dialog)
@@ -136,59 +130,58 @@ extensions_manager_ui_response_cb (GtkWidget *widget,
 	g_object_unref (dialog);
 }
 
-void
-extensions_manager_ui_info_dialog_response_cb (GtkWidget *widget,
-					       int response,
-					       GObject *dialog)
-{
-	g_object_unref (dialog);
-}
-
-static const char **
-string_list_to_array (GList *list)
-{
-	GList *l;
-	int i = 0;
-	const char **ret = malloc
-		((g_list_length (list) + 1) * sizeof (char *));
-
-	for (l = list; l; l = l->next)
-	{
-		ret[i++] = (const char *) l->data;
-	}
-
-	ret[i] = NULL;
-
-	return ret;
-}
-
 static void
 show_extension_info (ExtensionsManagerUI *parent_dialog,
 		     EphyExtensionInfo *info)
 {
+	GKeyFile *keyfile = info->keyfile;
 	GtkAboutDialog *dialog;
-	const char **authors;
+	char *name, *description, *url, **authors;
+
+	name = g_key_file_get_locale_string (keyfile, GROUP, "Name", NULL, NULL);
+	description = g_key_file_get_locale_string (keyfile, GROUP, "Description", NULL, NULL);
+	url = g_key_file_get_string (keyfile, GROUP, "URL", NULL);
+	authors = g_key_file_get_string_list (keyfile, GROUP, "Authors", NULL, NULL);
 
 	dialog = GTK_ABOUT_DIALOG (gtk_about_dialog_new ());
-	gtk_about_dialog_set_name (dialog, info->name);
-	gtk_about_dialog_set_comments (dialog, info->description);
-	gtk_about_dialog_set_website (dialog, info->url);
-
-	authors = string_list_to_array (info->authors);
+	gtk_about_dialog_set_name (dialog, name);
+	gtk_about_dialog_set_comments (dialog, description);
+	gtk_about_dialog_set_website (dialog, url);
 	gtk_about_dialog_set_authors (dialog, (const char **) authors);
-	free (authors);
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 				      GTK_WINDOW (parent_dialog->priv->window));
 	gtk_window_present (GTK_WINDOW (dialog));
+
+	g_free (name);
+	g_free (description);
+	g_free (url);
+	g_strfreev (authors);
 }
 
-static char *
-display_from_info (EphyExtensionInfo *info)
+static void
+store_extension (GtkListStore *store,
+		 EphyExtensionInfo *info)
 {
-	return g_strdup_printf ("<b>%s</b>\n%s",
-				info->name,
-				info->description);
+	GKeyFile *keyfile = info->keyfile;
+	GtkTreeIter iter;
+	char *name, *description, *display;
+
+	name = g_key_file_get_locale_string (keyfile, GROUP, "Name", NULL, NULL);
+	description = g_key_file_get_locale_string (keyfile, GROUP, "Description", NULL, NULL);
+	display = g_strdup_printf ("<b>%s</b>\n%s", name, description);
+
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+				COL_INFO, info,
+				COL_NAME, name,
+				COL_TOGGLE, info->active,
+				COL_DISPLAY, display,
+				-1);
+
+	g_free (name);
+	g_free (description);
+	g_free (display);
 }
 
 static void
@@ -197,8 +190,6 @@ fill_list_store (EphyExtensionsManager *manager,
 {
 	GList *extensions, *l;
 	EphyExtensionInfo *info;
-	GtkTreeIter iter;
-	char *display;
 
 	gtk_list_store_clear (store);
 
@@ -215,17 +206,7 @@ fill_list_store (EphyExtensionsManager *manager,
 		}
 #endif /* IGNORE_SELF */
 
-		gtk_list_store_append (store, &iter);
-
-		display = display_from_info (info);
-
-		gtk_list_store_set (store, &iter,
-				    COL_INFO, info,
-				    COL_TOGGLE, info->active,
-				    COL_DISPLAY, display,
-				    -1);
-
-		g_free (display);
+		store_extension (store, info);
 	}
 
 	g_list_free (extensions);
@@ -341,6 +322,9 @@ build_ui (ExtensionsManagerUI *dialog)
 	priv->treeview = ephy_dialog_get_control (EPHY_DIALOG (dialog),
 						  properties[PROP_TREEVIEW].id);
 
+	g_signal_connect (priv->window, "response",
+			  G_CALLBACK (extensions_manager_ui_response_cb), dialog);
+
 	gtk_window_set_icon_name (GTK_WINDOW (priv->window), GTK_STOCK_PREFERENCES);
 
 	treeview = GTK_TREE_VIEW (priv->treeview);
@@ -358,6 +342,7 @@ build_ui (ExtensionsManagerUI *dialog)
 						     NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
+	g_object_set (G_OBJECT (renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
 	gtk_tree_view_insert_column_with_attributes (treeview,
 						     COL_DISPLAY, _("Description"),
 						     renderer,
@@ -366,6 +351,7 @@ build_ui (ExtensionsManagerUI *dialog)
 
 	store = gtk_list_store_new (N_COLUMNS,
 				    G_TYPE_POINTER,
+				    G_TYPE_STRING,
 				    G_TYPE_BOOLEAN,
 				    G_TYPE_STRING);
 	fill_list_store (dialog->priv->manager, store);
@@ -374,6 +360,8 @@ build_ui (ExtensionsManagerUI *dialog)
 
 	gtk_tree_view_set_model (treeview, GTK_TREE_MODEL (store));
 
+	gtk_tree_view_set_search_column (treeview, COL_NAME);
+
 	priv->model = GTK_TREE_MODEL (store);
 	g_object_unref (store);
 }
@@ -383,28 +371,9 @@ extension_added_cb (EphyExtensionsManager *manager,
 		    EphyExtensionInfo *info,
 		    ExtensionsManagerUI *dialog)
 {
-	GtkTreeView *treeview;
-	GtkListStore *store;
-	GtkTreeIter iter;
-	char *display;
+	ExtensionsManagerUIPrivate *priv = dialog->priv;
 
-	treeview = GTK_TREE_VIEW (dialog->priv->treeview);
-	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
-
-	store = GTK_LIST_STORE (gtk_tree_view_get_model (treeview));
-	g_return_if_fail (GTK_IS_LIST_STORE (store));
-
-	gtk_list_store_append (store, &iter);
-
-	display = display_from_info (info);
-
-	gtk_list_store_set (store, &iter,
-			    COL_INFO, info,
-			    COL_TOGGLE, info->active,
-			    COL_DISPLAY, display,
-			    -1);
-
-	g_free (display);
+	store_extension (GTK_LIST_STORE (priv->model), info);
 }
 
 static void
@@ -412,12 +381,11 @@ extension_removed_cb (EphyExtensionsManager *manager,
 		      EphyExtensionInfo *info,
 		      ExtensionsManagerUI *dialog)
 {
-	GtkTreeModel *model;
+	ExtensionsManagerUIPrivate *priv = dialog->priv;
+	GtkTreeModel *model = priv->model;
 	GtkTreeIter iter;
 	EphyExtensionInfo *row_info;
 
-	model = dialog->priv->model;
-
 	if (gtk_tree_model_get_iter_first (model, &iter) == FALSE) return;
 
 	do
