@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.11.4.2 2005/10/10 19:02:46 chpe Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.14 2005/11/02 21:41:42 chpe Exp $
  */
 
 #include "config.h"
@@ -230,8 +230,7 @@ show_context_menu (EphySidebarEmbed *sbembed,
 	}
 	else
 	{
-		popup = framed ? "/EphySidebarFramedDocumentPopup" :
-				 "/EphySidebarDocumentPopup";
+		popup = "/EphySidebarDocumentPopup";
 	}
 
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
@@ -256,6 +255,9 @@ show_context_menu (EphySidebarEmbed *sbembed,
 	gtk_action_set_sensitive (action, can_paste);
 	gtk_action_set_visible (action, !hide_edit_actions || can_paste);
 
+	action = gtk_ui_manager_get_action (manager, "/EphyDocumentPopup/OpenFrameFDP");
+	gtk_action_set_visible (action, framed);
+
 	_ephy_window_set_context_event (window, event);
 
 	widget = gtk_ui_manager_get_widget (manager, popup);
